@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.1.2.21 2006/04/20 13:52:47 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.1.2.22 2006/09/18 08:54:50 renaud Exp $
  */
 #include <includes.h>
 
@@ -773,6 +773,7 @@ error:
 int proxy_connect_method(char * hostname, int port, struct preferences * prefs, struct arglist * hostinfo)
 {
  char buf[1024];
+ char ua[512];
  const char * base64;
  char proxy_auth[256];
  static SSL_CTX        *ssl_ctx = NULL;
@@ -781,6 +782,8 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
  int n;
  int fd, soc;
 
+ snprintf(ua, sizeof(ua), "Nessus-Fetch/%s", nessuslib_version());
+
 
 	if ( prefs->proxy_username != NULL && prefs->proxy_password != NULL )
 	{
@@ -792,7 +795,7 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
 
   	soc = open_stream_connection ( hostinfo, atoi(prefs->proxy_port), NESSUS_ENCAPS_IP, SOCKET_TIMEOUT );
        fd = nessus_get_socket_from_connection(soc); 
-	snprintf(buf, sizeof(buf), "CONNECT %s:%d HTTP/1.0\r\nUser-Agent: Mozilla/4.73 (Win95;I)\r\n%s\r\n", hostname, port, proxy_auth);
+	snprintf(buf, sizeof(buf), "CONNECT %s:%d HTTP/1.0\r\nUser-Agent: %s\r\n%s\r\n", hostname, port, ( prefs->user_agent != NULL && prefs->user_agent[0] != '\0' ) ? prefs->user_agent : ua, proxy_auth);
 	write_stream_connection ( soc, buf, strlen(buf) );
 	n = read_stream_connection(soc, buf, sizeof(buf) - 1);
 	if ( n < 0 || strstr(buf, " 200 " ) == NULL || strstr(buf, "\r\n\r\n") == NULL )
