@@ -9,6 +9,7 @@
 
 #define GDC_INCL
 #define GDC_LIB
+#define GDC_VARS
 #include "gdc.h"
 #include "gdchart.h"
 
@@ -38,6 +39,17 @@
 #ifndef MAXINT
 # define MAXINT INT_MAX
 #endif
+ 
+
+/* 
+ * MkLinux defines MAXSHORT as SHORT_MAX, but does not
+ * define SHORT_MAX. However, it defines a SHRT_MAX
+ */
+#ifndef SHORT_MAX
+#ifdef SHRT_MAX
+#define SHORT_MAX SHRT_MAX
+#endif
+#endif
 
 #define HIGHSET		0
 #define LOWSET		1
@@ -55,9 +67,9 @@
 
 #ifdef THUMB_VALS
 /* -------------------------------------------------------------------
-/* draw an arrow at (x,y)-upper left in arrwclr to the size of SmallFont*/
-/* could, with just a little difficulty, be made to accept a font size*/
-/* ------------------------------------------------------------------- */*/
+ * draw an arrow at (x,y)-upper left in arrwclr to the size of SmallFont
+ * could, with just a little difficulty, be made to accept a font siz
+ * ------------------------------------------------------------------- */
 void
 smallarrow( gdImagePtr  im,
 			int			x,
@@ -124,14 +136,6 @@ draw_3d_line( gdImagePtr	im,
 				*slope = (float*)alloca (num_sets * sizeof (float));
 #else
 				slope[num_sets];
-#endif /* USE_ALLOCA */
-	int			
-#ifdef USE_ALLOCA
-				*lnclr = (int*)alloca (num_sets * sizeof (int)),
-				*shclr = (int*)alloca (num_sets * sizeof (int));
-#else
-				lnclr[num_sets],
-				shclr[num_sets];
 #endif /* USE_ALLOCA */
 	int			i;
 	int			x;
@@ -329,14 +333,14 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 						... )
 {
 	va_list		ap;
-	int			i, j, k;
+	int			i, j;
 
 	int			graphwidth;
 	int			grapheight;
 	gdImagePtr	im;
 	gdImagePtr	bg_img = NULL;
 
-	float		xorig, yorig, vyorig;
+	float		xorig, yorig, vyorig = 0.0;
 	float		yscl     = 0.0;
 	float		vyscl    = 0.0;
 	float		xscl     = 0.0;
@@ -344,7 +348,6 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 	float		vlowest  = MAXFLOAT;
 	float		highest  = -MAXFLOAT;
 	float		lowest   = MAXFLOAT;
-	gdPoint     volpoly[4];
 
 	char		do_vol = ( type == GDC_COMBO_HLC_BAR   ||		/* aka: combo */
 						   type == GDC_COMBO_HLC_AREA  ||
@@ -406,24 +409,21 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 	float		*uvals[ _dim_];
 #endif /* USE_ALLOCA */
 
-	float		*uvol;
+	float		*uvol = NULL;
 
 	int			BGColor,
 				LineColor,
 				PlotColor,
 				GridColor,
-				VolColor,
+				VolColor = 0,
 #ifdef USE_ALLOCA
 				*ExtVolColor = (int*)alloca (num_points * sizeof (int)),
 #else
 				ExtVolColor[num_points],
 #endif /* USE_ALLOCA */
-				ThumbDColor,
-				ThumbLblColor,
-				ThumbUColor,
 /*				ArrowDColor,*/
 /*				ArrowUColor,*/
-				AnnoteColor,
+				AnnoteColor = 0,
 #ifdef USE_ALLOCA
 				*ExtColor = (int*)alloca (num_sets * num_points * sizeof (int));
 #else
@@ -484,10 +484,12 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 					pos_set_sum = 0.0;
 			for( i=0; i<num_sets; ++i )
 				if( uvals[i][j] != GDC_NOVALUE )
+				{
 					if( uvals[i][j] < 0.0 )
 						neg_set_sum += uvals[i][j];
 					else
 						pos_set_sum += uvals[i][j];
+				}
 			lowest  = MIN( lowest,  MIN(neg_set_sum,pos_set_sum) );
 			highest = MAX( highest, MAX(neg_set_sum,pos_set_sum) );
 			}
@@ -532,11 +534,13 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 		type == GDC_BAR   ||
 		type == GDC_3DBAR ||
 		type == GDC_3DAREA )
+		{
 		if( highest < 0.0 )
 			highest = 0.0;
 		else
 		if( lowest > 0.0 )						/* negs should be drawn from 0*/
 			lowest = 0.0;
+		}
 
 	if( GDC_requested_ymin != GDC_NOVALUE && GDC_requested_ymin < lowest )
 		lowest = GDC_requested_ymin;
@@ -583,7 +587,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 
 	if( GDC_xaxis && xlbl )
 		{
-		int biggest     = -MAXINT;
+		int biggest     = 0 - (MAXINT);
 
 		for( i=0; i<num_points; ++i )
 			{
@@ -747,7 +751,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 				+ ydepth_3Dtotal
 				+ title_hgt
 				+ annote_hgt;
-/*????	if( GDC_hard_size && GDC_hard_yorig )			/*/
+/*????	if( GDC_hard_size && GDC_hard_yorig )			*/
 /*????		yorig = GDC_hard_yorig;*/
 	GDC_hard_yorig = yorig;
 
@@ -793,7 +797,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 			}
 		else
 			{
-			if( bg_img = gdImageCreateFromGif(in) )					/* =*/
+			if( (bg_img = gdImageCreateFromGif(in)) != 0 )					/* =*/
 				{
 				int	bgxpos = gdImageSX(bg_img)<GIFWIDTH?  GIFWIDTH/2 - gdImageSX(bg_img)/2:  0,
 					bgypos = gdImageSY(bg_img)<GIFHEIGHT? GIFHEIGHT/2 - gdImageSY(bg_img)/2: 0;
@@ -888,16 +892,16 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 		/* if lowest < 0 < highest                                                  */
 		for( i=-1; i<=1; i+=2 )									/* -1, 1*/
 			{
-			if( i == -1 )	if( lowest >= 0.0 )					/*	all pos plotting*/
+			if( i == -1 ) {	if( lowest >= 0.0 )					/*	all pos plotting*/
 								continue;
 							else
 								tmp_y = MIN( 0, highest );		/*	step down to lowest*/
-
-			if( i == 1 )	if( highest <= 0.0 )				/*	all neg plotting*/
+					}
+			if( i == 1 )   {if( highest <= 0.0 )				/*	all neg plotting*/
 								continue;
 							else
 								tmp_y = MAX( 0, lowest );		/*	step up to highest*/
-
+					}
 #if 0
 //			if( !(highest > 0 && lowest < 0) )					/* doesn't straddle 0*/
 /*				{*/
@@ -938,7 +942,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 					gdImageLine( im, x2, y2, PX(num_points-1+(do_bar?2:0)), y2, GridColor );
 					setno = 0;											/* set back to foremost*/
 					}
-				if( GDC_yaxis )
+				if( GDC_yaxis ) {
 					if( do_ylbl_fractions )
 						{
 						if( w || (!w && !n && !d) )
@@ -988,7 +992,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 									  (u_char*)ylbl_str,
 									   labelcolor );
 
-
+					}
 				if( do_vol && GDC_yaxis2 )
 					{
 					char	vylbl[16];
@@ -1094,7 +1098,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 		int		num_xlbls =										/* maximum x lables that'll fit */
 																/* each xlbl + avg due to num_lf_xlbls */
 					graphwidth /
-						( (GDC_xlabel_spacing==MAXSHORT?0:GDC_xlabel_spacing)+GDC_fontc[GDC_xaxisfont_size].h +
+						( (GDC_xlabel_spacing== (MAXSHORT) ?0:GDC_xlabel_spacing)+GDC_fontc[GDC_xaxisfont_size].h +
 						  (num_lf_xlbls*(GDC_fontc[GDC_xaxisfont_size].h-1))/num_points );
 		int		labelcolor = GDC_XLabelColor==GDC_DFLTCOLOR? 
 							 LineColor: clrallocate( im, GDC_XLabelColor );
@@ -1102,7 +1106,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 		for( i=0; i<num_points+(do_bar?2:0); ++i )
 			if( (i%(1+num_points/num_xlbls) == 0) ||					/* # x labels are regulated*/
 				(num_xlbls >= num_points)         ||
-				GDC_xlabel_spacing == MAXSHORT )
+				GDC_xlabel_spacing == (MAXSHORT) )
 				{
 				int	xi = do_bar? i-1: i;
 
@@ -1246,12 +1250,6 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 
 			case GDC_STACK_LAYER:
 				{
-				float
-#ifdef USE_ALLOCA
-						*lasty = (float*)alloca (num_points * sizeof (float));
-#else
-						lasty[num_points];
-#endif /* USE_ALLOCA */
 				j = 0;
 /*				for( i=0; i<num_points; ++i )*/
 /*					if( uvals[j][i] != GDC_NOVALUE )*/
@@ -1325,7 +1323,10 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 											 threeD? ExtColorShd I(j,i): ExtColor I(j,i) );
 					}
 				break;
+			default:
+				break;
 			}
+			
 			break;
 
 		case GDC_LINE:
@@ -1714,11 +1715,13 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 					ct[2].x = scat_x + hlf_scatterwdth;
 					ct[2].y = scat_y + hlf_scatterwdth;
 					if( !do_bar )
+						{
 						if( (GDC_scatter+i)->point == 0 )
 							ct[1].x = scat_x;
 						else
 						if( (GDC_scatter+i)->point == num_points-1 )
 							ct[2].x = scat_x;
+						}
 					gdImageFilledPolygon( im, ct, 3, scatter_clr[i] );
 					break;
 				case GDC_SCATTER_TRIANGLE_DOWN:
@@ -1729,11 +1732,13 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 					ct[2].x = scat_x + hlf_scatterwdth;
 					ct[2].y = scat_y - hlf_scatterwdth;
 					if( !do_bar )
+						{
 						if( (GDC_scatter+i)->point == 0 )
 							ct[1].x = scat_x;
 						else
 						if( (GDC_scatter+i)->point == num_points-1 )
 							ct[2].x = scat_x;
+						}
 					gdImageFilledPolygon( im, ct, 3, scatter_clr[i] );
 					break;
 				}
@@ -1768,7 +1773,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 			int		thmbvalwidth = SFONTWDTH 					  +	/* up/down arrow*/
 								   (w?strlen(whole)*SFONTWDTH: 0) +	/* whole*/
 								   (n?strlen(nmrtr)*TFONTWDTH	  +	/* numerator*/
-									  SFONTWDTH					  +	/* /*/
+									  SFONTWDTH					  +	
 									  strlen(dmntr)*TFONTWDTH:		/* denominator*/
 									  0);							/* no frac part*/
 
@@ -1808,7 +1813,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 							   SFONTWDTH					  +		/* arrow*/
 							   (w? strlen(whole)*SFONTWDTH: 0) +		/* whole*/
 							   strlen(nmrtr)*TFONTWDTH		  +		/* numerator*/
-							   SFONTWDTH - 3,						/* /*/
+							   SFONTWDTH - 3,						/* */
 							   SFONTHGT+2+4,
 							   dmntr,
 							   chgcolor );
@@ -1933,7 +1938,7 @@ out_graph( short		GIFWIDTH,		/* no check for a gif that's too small to fit */
 }
 
 
-/* $Id: gdchart.c,v 1.4 2000/10/29 00:21:59 renaud Exp $
+/* $Id: gdchart.c,v 1.7 2003/05/21 16:30:47 renaud Exp $
  * local variables:
  * mode: c
  * tab-width: 4
