@@ -78,7 +78,7 @@
 static void insert_img(FILE *, char*);
 
 
-extern int out_graph(short, short, FILE *, GDC_CHART_T, int, char **, int, float *);
+extern int out_graph(short, short, FILE *, GDC_CHART_T, int, char **, int, ...);
 
 
 
