@@ -30,7 +30,7 @@
 #define MSG_FINISHED 9
 #define MSG_STAT2 10
 #define MSG_NOTE 11
-
+#define MSG_TIME 12
 
 #define MSG_ERROR_STR "ERROR"
 #define MSG_PORT_STR "PORT"
@@ -42,14 +42,16 @@
 #define MSG_PING_STR "PING"
 #define MSG_PLUGINS_ORDER_STR "PLUGINS_ORDER"
 #define MSG_FINISHED_STR "FINISHED"
+#define MSG_TIME_STR "TIME"
 
 int parse_message_type(char *);
-int parse_server_message(char *, struct arglist *, char *);
-void parse_host_add_port(struct arglist *, char *, char *);
-void parse_host_add_data(struct arglist *, char *, int);
+int parse_server_message(char *,  int,  char *);
+void parse_host_add_port(int, char *, char *);
+void parse_host_add_data(int, char *, int);
 char * parse_plugin_symbol(char *);
 char * parse_separator(char *);
 char * parse_symbol(char *);
-void parse_nessusd_status(char *, char *, char *, char  **, int *);
+void parse_nessusd_status(char *, char **, char **, char  **, int *);
+void parse_nessusd_short_status(char *, char **, char **, char  **, int *);
 
 #endif
