@@ -20,6 +20,9 @@
 #define _NESSUSD_AUTH_H
 
 #include "users.h"
-struct nessus_rules * auth_check_user(struct arglist *, char *);
+
+extern char *per_user_pfx;
+extern struct nessus_rules * auth_check_user(struct arglist *, char *, char*);
+extern int user_lookup (const char *uname);
 
 #endif
