@@ -193,6 +193,35 @@ nasl_thread(g_args)
  {
   close(i);
  }
+ #ifdef RLIMIT_RSS	 
+  {	 
+  struct rlimit rlim;	 
+  getrlimit(RLIMIT_RSS, &rlim);	 
+  rlim.rlim_cur = 1024*1024*512;	 
+  rlim.rlim_max = 1024*1024*512;	 
+  setrlimit(RLIMIT_RSS, &rlim);	 
+  }	 
+ #endif	 
+ 	 
+ #ifdef RLIMIT_AS	 
+  {	 
+  struct rlimit rlim;	 
+  getrlimit(RLIMIT_AS, &rlim);	 
+  rlim.rlim_cur = 1024*1024*512;	 
+  rlim.rlim_max = 1024*1024*512;	 
+  setrlimit(RLIMIT_AS, &rlim);	 
+  }	 
+ #endif	 
+ 	 
+ #ifdef RLIMIT_DATA	 
+  {	 
+  struct rlimit rlim;	 
+  getrlimit(RLIMIT_DATA, &rlim);	 
+  rlim.rlim_cur = 1024*1024*512;	 
+  rlim.rlim_max = 1024*1024*512;	 
+  setrlimit(RLIMIT_DATA, &rlim);	 
+  }	 
+ #endif
  setproctitle("testing %s (%s)", (char*)arg_get_value(arg_get_value(args, "HOSTNAME"), "NAME"), (char*)arg_get_value(g_args, "name"));
  signal(SIGTERM, _exit);
  
