@@ -975,6 +975,9 @@ ntp_1x_send_dependencies(globals)
    if(strlen(fname) + strlen(buf) + 6 > buf_size)
    {
     buf_size *= 2;
+    if(strlen(fname) + strlen(buf) + 6 > buf_size)
+    	buf_size = strlen(fname) + strlen(buf) + 6;
+
     buf = erealloc(buf, buf_size);
    }
    strncat(buf, fname, buf_size);
