@@ -24,6 +24,7 @@ int    preferences_new(char *);
 int    preferences_process(char *, struct arglist *);
 
 int    preferences_get_host_expansion(struct arglist *);
+int    preferences_get_slice_network_addresses(struct arglist *);
 int    preferences_get_checks_read_timeout(struct arglist*);
 int    preferences_get_delay_between_tests(struct arglist *);
 int    preferences_log_whole_attack(struct arglist *);
@@ -54,5 +55,8 @@ char * preferences_detached_scan_email(struct arglist *);
 
 void  preferences_reset_cache();
 int   preferences_user_is_admin(struct arglist* , struct arglist *);
+int   preferences_silent_dependencies(struct arglist*);
+
+int  preferences_nasl_no_signature_check(struct arglist * );
 
 #endif
